package com.xicoo.flutter_plugin.xicoo_flutter_plugin;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.Environment;

import androidx.annotation.NonNull;

import java.io.File;
import java.util.List;

import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** XicooFlutterPlugin */
public class XicooFlutterPlugin implements ActivityAware,FlutterPlugin, MethodCallHandler{
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private String args = "";
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "xicoo_start_param");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    args = binding.getActivity().getIntent().getStringExtra("param");
    activity = binding.getActivity();
    Log.i("onAttachedToActivity",args);
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    args = "";
    Log.i("onAttachedToActivity","onDetachedFromActivityForConfigChanges");
  }

  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    args = binding.getActivity().getIntent().getStringExtra("param");
    Log.i("onReattachedToActivityForConfigChanges",args);
  }

  @Override
  public void onDetachedFromActivity() {
    args = "";
    activity = null;
    Log.i("onDetachedFromActivity","onDetachedFromActivityForConfigChanges");
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method){
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "getStartParam":
        result.success(args);
        break;
      case "startMark":
        startMark();
        result.success(true);
        break;
      case "exit":
        if(activity != null){
          activity.finish();
        }
        System.exit(0);
        result.success(true);
        break;
      case "getXicooFileRoot":
        result.success(Environment.getExternalStorageDirectory() + File.separator);
        break;
    }
  }

  public void startMark(){
    if(installed("com.dss.singlemark")){
      ComponentName markComponent = new ComponentName("com.dss.singlemark", "com.dss.singlemark.LaunchService");
      Intent intent = new Intent();
      intent.setComponent(markComponent);
      intent.putExtra("side","MARK_OPEN_WHICH_SIDE");
      intent.putExtra("sideValue","1");
      intent.setAction("com.dss.singlemark.action.OPEN_MARK");
      activity.startService(intent);
    }else{
      ComponentName markComponent =new ComponentName("com.cvte.maxhub.mark", "com.cvte.maxhub.mark.launch.LaunchService");
      Intent intent = new Intent();
      intent.setComponent(markComponent);
      intent.setAction("com.cvte.maxhub.mark.action.OPEN_MARK");
      intent.putExtra("side","MARK_OPEN_WHICH_SIDE");
      intent.putExtra("sideValue","1");
      activity.startService(intent);
    }
  }

  public boolean installed(String appPackageName) {
    PackageManager packageManager = activity.getPackageManager();// 获取packagemanager
    List<PackageInfo> pinfo = packageManager.getInstalledPackages(0);// 获取所有已安装程序的包信息
    for (PackageInfo pkif : pinfo) {
      String pn = pkif.packageName;
      if (appPackageName.equals(pn)) {
        return true;
      }
    }
    return false;
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
